#ifndef __KYLINMOUSEINTERFACE_H__
#define __KYLINMOUSEINTERFACE_H__

#include <stdbool.h>

#ifdef __cplusplus
extern "C" {
#endif

//Initialize the DBus Communication
bool InitDBusMouse(void);

//Delete the DBus Communication
bool DeInitDBusMouse(void);

/*
 * Swap left and right mouse buttons for left-handed mice.
 *
 */
void kylin_hardware_mouse_lefthanded(const bool in_arg);

/*
 * Acceleration multiplier for mouse motion.
 * A value of -1 is the system default
 */
void kylin_hardware_mouse_motionacceleration(const double in_arg);

/*
 * Distance in pixels the pointer must move
 * before accelerated mouse motion is activated.
 * A value of -1 is the system default.
 */
void kylin_hardware_mouse_motionthreshold(const int in_arg);

/*
 * Distance before a drag is started.
 */
void kylin_hardware_mouse_dragthreshold(const int in_arg);

/*
 * Length of a double click
 */
void kylin_hardware_mouse_doubleclick(const int in_arg);

/*
 * Enables middle mouse button emulation
 * through simultaneous left and right button click.
 */
void kylin_hardware_mouse_middlebuttonenabled(const bool in_arg);

/*
 * Highlights the current location of the pointer
 * when the Control key is pressed and released.
 */
void kylin_hardware_mouse_locatepointer(const bool in_arg);

/*
 * Font name of the cursor. If unset, the default font is used.
 * This value is only propagated to the X server start of each session,
 * so changing it mid-session won't have an effect until the next time you log in.
 */
void kylin_hardware_mouse_cursorfont(const char *in_arg);

/*
 * Cursor theme name. Used only by Xservers that support Xcursor,
 * such as XFree86 4.3 and later.
 */
void kylin_hardware_mouse_cursortheme(const char *in_arg);

/*
 * Size of the cursor referenced by cursor_theme.
 */
void kylin_hardware_mouse_cursorsize(const int in_arg);

#ifdef __cplusplus
}
#endif

#endif













