#ifndef __KYLINNETWORKINTERFACE_H__
#define __KYLINNETWORKINTERFACE_H__

#include<stdio.h>

#ifdef __cplusplus
extern "C"{
#endif

/*
 * Get the network interface information.
 * @if_name is used to save the interface name.
 * return the interface number.
 */
int kylin_network_network_getifacename(char **if_name);

/* Get the ip address.
 * @if_name is the interface name.
 * @ipaddr is used to save the ip address.
 */
int kylin_network_network_getipaddr(char *if_name,char *ipaddr);

/*
 * Set the ip address.
 * @if_name is the interface name.
 * @ipaddr is the ip address that need to be set.
 */
int kylin_network_network_setip(char *if_name,char *ipaddr);

/*
 * Get the broadcast address.
 * @if_name is the interface name.
 * @brdaddr is used to save the broadcast address.
 */
int kylin_network_network_getbrdaddr(char *if_name,char *brdaddr);

/*
 * Set the broadcast address.
 * @if_name is the interface name.
 * @brdaddr is the broadcast address that need to be set.
 */
int kylin_network_network_setbrdaddr(char *if_name,char *brdaddr);

/*
 * Get the subnet mask.
 * @if_name is the interface name.
 * @netmask is used to save the subnet mask.
 */
int kylin_network_network_getnetmask(char *if_name,char *netmask);

/* Set the subnet mask.
 * @if_name is the interface name.
 * @netmask is the subnet mask that need to be set.
 */
int kylin_network_network_setnetmask(char *if_name,char *netmask);

/*
 * Add routing tables.
 * @gateway is the gateway address that need to be added.
 */
int kylin_network_network_addgateway(char *gateway);

/*
 * Delete routing tables.
 * @gateway is the gateway address that need to be deleted.
 */
int kylin_network_network_delgateway(char *gateway);

/*
 * Get MAC address.
 * @if_name is the interface name.
 * @macaddr is used to save the MAC address.
 */
int kylin_network_network_getmac(char *if_name,char *macaddr);

/*
 * Enable network interface.
 * @if_name is the interface name that need to be enabled.
 */
int kylin_network_network_setifup(char *if_name);

/*
 * Disabled network interface.
 * @if_name is the interface name that need to be disabled.
 */
int kylin_network_network_setifdown(char *if_name);

/* Get the MTU.
 * @if_name is the interface name.
 * return the MTU value.
 */
int kylin_network_network_getmtu(char *if_name);

#ifdef __cplusplus
}
#endif

#endif
